import json
import requests

from jdOctopus.index import newOctopus
from jdOctopus.tool import interceptor

class point:

    @staticmethod
    def clickLong(x, y, time, uuids=""):
        octopus = newOctopus()
        if uuids == "":
            uuids = octopus.devices
        url = octopus.addr + "/clickLong"
        data = {
            'uuids': uuids,
            'x': x,
            'y': y,
            'time': time
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=octopus.headers).text)
        interceptor(text)

    @staticmethod
    def clickByPixel(x, y, uuids=""):
        octopus = newOctopus()
        if uuids == "":
            uuids = octopus.devices
        url = octopus.addr + "/clickByPixel"
        data = {
            'uuids': uuids,
            'x': x,
            'y': y
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=octopus.headers).text)
        interceptor(text)

    @staticmethod
    def clickByPercentage(x, y, uuids=""):
        octopus = newOctopus()
        if uuids == "":
            uuids = octopus.devices
        url = octopus.addr + "/clickByPercentage"
        data = {
            'uuids': uuids,
            'x': x,
            'y': y
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=octopus.headers).text)
        interceptor(text)


import json
import requests

from jdOctopus.index import newOctopus
from jdOctopus.tool import interceptor
from requests_toolbelt import MultipartEncoder

class device:

    @staticmethod
    def getOnline():
        octopus = newOctopus()
        url = octopus.addr + "/getDevices"
        text = json.loads(requests.get(url=url, headers=octopus.headers).text)
        interceptor(text)
        return text["data"]

    @staticmethod
    def getBindInfo():
        octopus = newOctopus()
        url = octopus.addr + "/bindDevicesInfo"
        text = json.loads(requests.get(url=url, headers=octopus.headers).text)
        interceptor(text)
        return text["data"]

    @staticmethod
    def bindDevices(uuids):
        octopus = newOctopus()
        url = octopus.addr + "/bindDevices"
        data = {
            'uuids': uuids
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=octopus.headers).text)
        interceptor(text)
        for each in uuids:
            octopus.devices.append(each)

    @staticmethod
    def unBindDevices(uuids):
        octopus = newOctopus()
        url = octopus.addr + "/unBindDevices"
        data = {
            'uuids': uuids
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=octopus.headers).text)
        interceptor(text)
        for each in uuids:
            octopus.devices.remove(each)

    @staticmethod
    def screenCapture(imgPath="./", zoom=4, uuids=""):
        octopus = newOctopus()
        if uuids == "":
            uuids = octopus.devices
        for each in uuids:
            url = octopus.addr + "/screenCapture"
            data = {
                'uuids': [each],
                'zoom': zoom
            }
            res = requests.post(url=url, data=json.dumps(data), headers=octopus.headers)
            sub_str = imgPath[-4:]
            ip = imgPath
            if sub_str!='.png' and sub_str!='.jpg':
                filename = ''
                resheader = str(res.headers['content-disposition'])
                indirect = resheader[resheader.rfind('=')+1:]
                if indirect and len(indirect)>0:
                    filename = indirect + '.png'
                ip += filename

            if res.headers["content-type"] == "application/octet-stream":
                with open(ip, 'wb') as f:
                    f.write(res.content)
                    f.close()
            else:
                text = json.loads(res.text)
                interceptor(text)

    @staticmethod
    def addFile(filePath, savePath, uuids=""):
        octopus = newOctopus()
        if uuids == "":
            uuids = octopus.devices
        url = octopus.addr + "/addFile"
        data = MultipartEncoder(fields={'uuids': str(uuids).replace("'", '"'),  'savepath': savePath,
                                     'file': ("weixin.png", open(filePath, 'rb'))})
        header = {
            'Content-Type': data.content_type, 'Uuid': octopus.headers["Uuid"]
        }
        text = json.loads(requests.post(url=url, headers=header, data=data).text)
        interceptor(text)

    @staticmethod
    def runKeyCode(code, uuids=""):
        octopus = newOctopus()
        if uuids == "":
            uuids = octopus.devices
        url = octopus.addr + "/runKeyCode"
        data = {
            'uuids': uuids,
            'text': str(code)
        }
        print(data)
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=octopus.headers).text)
        interceptor(text)

    @staticmethod
    def startApp(packageName, uuids=""):
        octopus = newOctopus()
        if uuids == "":
            uuids = octopus.devices
        url = octopus.addr + "/startApp"
        data = {
            'uuids': uuids,
            'text': packageName
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=octopus.headers).text)
        interceptor(text)


import json
import requests
from jdOctopus.index import newOctopus
from jdOctopus.tool import interceptor, exist
from requests_toolbelt import MultipartEncoder

class img:

    def __init__(self, imgPath):
        octopus = newOctopus()
        self.addr = octopus.addr
        self.devices = octopus.devices
        self.headers = octopus.headers
        self.imgPath = imgPath

    def click(self, uuids=""):
        if uuids == "":
            uuids = self.devices
        url = self.addr + "/clickByImage"
        data = MultipartEncoder(fields={'uuids': str(uuids).replace("'", '"'), 'imgPath': self.imgPath,
                                     'img': ("weixin.png", open(self.imgPath, 'rb'))})
        header = {
            'Content-Type': data.content_type, 'Uuid': self.headers["Uuid"]
        }
        text = json.loads(requests.post(url=url, headers=header, data=data, timeout=5).text)
        interceptor(text)

    def exists(self, uuids=""):
        if uuids == "":
            uuids = self.devices
        url = self.addr + "/existImage"
        data = MultipartEncoder(fields={'uuids': str(uuids).replace("'", '"'), 'imgPath': self.imgPath,
                                     'img': ("weixin.png", open(self.imgPath, 'rb'))})
        header = {
            'Content-Type': data.content_type, 'Uuid': self.headers["Uuid"]
        }
        text = json.loads(requests.post(url=url, headers=header, data=data).text)
        return exist(text)

    def save(self, savePath, uuids=""):
        if uuids == "":
            uuids = self.devices
        url = self.addr + "/addImg"
        data = MultipartEncoder(fields={'uuids': str(uuids).replace("'", '"'), 'imgPath': self.imgPath, 'savepath': savePath,
                                     'img': ("weixin.png", open(self.imgPath, 'rb'))})
        header = {
            'Content-Type': data.content_type, 'Uuid': self.headers["Uuid"]
        }
        text = json.loads(requests.post(url=url, headers=header, data=data).text)
        interceptor(text)

    def getPointsByImage(self, uuids=""):
        if uuids == "":
            uuids = self.devices
        url = self.addr + "/getPointsByImage"
        data = MultipartEncoder(fields={'uuids': str(uuids).replace("'", '"'), 'imgPath': self.imgPath,
                                     'img': ("weixin.png", open(self.imgPath, 'rb'))})
        header = {
            'Content-Type': data.content_type, 'Uuid': self.headers["Uuid"]
        }
        text = json.loads(requests.post(url=url, headers=header, data=data).text)
        interceptor(text)
        return text["data"]


from time import sleep
from octopus_py.index import newOctopus
from octopus_py.model import *

newOctopus("10.222.50.39:8080")
uuid = ["7e:03:ab:92:73:13"]
device.bindDevices(uuid)

def slideDown(x):
    point.clickByPixel(540,450)
    sleep(2)
    for i in range(x):
        point.clickByPixel(540,1902)
        sleep(1)
    point.clickByPixel(950,1350)
    sleep(3)

def qiehuan(x,y,shangquan,city):
    for j in range(len(shangquan)):
        if j >12 :
            y = 2164
            for i in range(j-12):
                swipe.verticalRoll(0.0625)
                sleep(2)

        point.clickByPixel(x,y)
        sleep(2)
        point.clickByPixel(50,270)
        sleep(2)
        y+=124

img("./img/趣玩街.png").click()
sleep(4)
img("./img/允许.png").click()
sleep(2)
point.clickByPixel(50, 270)
sleep(2)
cityList= ["上海","佛山","北京","厦门","广州","西安","郑州","重庆"]
for i in range(len(cityList)):
    x = 200
    y = 676
    if i == 0 :
        list =["世纪汇广场","世博源广场","百联中环购物广场","静安大悦城","爱琴海微站","世茂广场","爱琴海B1"]
        slideDown(i)
        qiehuan(x,y,list,cityList[i])
    if i == 1 :
        list = ["九珑璧支行", "季华支行", "澜普支行", "世纪康城支行", "盛南新都支行", "影萌路支行", "锦华支行", "绿景三路支行", "大福南支路", "普君新城支路", "广佛路支行",
                "同济支行", "同福路支行", "东方水岸支行", "榴子支行", "莲华支行", "厚辉支行", "江湾支行", "威尔斯广场支行", "佛平路支行"]
        slideDown(i)
        qiehuan(x,y,list,cityList[i])
    if i == 2 :
        list = ["京东6号楼四层C1区09", "京东商超移动点位5区"]
        slideDown(i)
        qiehuan(x,y,list,cityList[i])

    if i == 3 :
        list = ["厦门国际会议展览中心"]
        slideDown(i)
        qiehuan(x,y,list,cityList[i])

    if i == 4 :
        list = ["中国银行广州合景支行"]
        slideDown(i)
        qiehuan(x,y,list,cityList[i])

    if i == 5 :
        list = ["西安曲江大悦城"]
        slideDown(i)
        qiehuan(x,y,list,cityList[i])

    if i == 6 :
        list = ["郑州农商银行老鸦陈支部"]
        slideDown(i)
        qiehuan(x,y,list,cityList[i])

    if i == 7 :
        list = ["京东电器超级体验店"]
        slideDown(i)
        qiehuan(x,y,list,cityList[i])

device.runKeyCode(4)
sleep(2)
device.runKeyCode(3)
sleep(2)



import uuid
import json
import requests
from jdOctopus.tool import interceptor

octopus = None

class Octopus:
    def __init__(self, add="localhost:8080"):
        self.addr = 'http://' + add + '/api'
        self.uuid = uuid.uuid1()
        self.headers = {
            'Uuid': str(self.uuid),
            'Content-Type': 'application/json',
        }
        self.devices = []

    def ping(self):
        url = self.addr + "/ping"
        text = json.loads(requests.get(url=url, headers=self.headers).text)
        interceptor(text)

def newOctopus(add="localhost:8080"):
    global octopus
    if octopus is None:
        octopus = Octopus(add)
    return octopus


from jdOctopus.model.text import text
from jdOctopus.model.device import device
from jdOctopus.model.img import img
from jdOctopus.model.info import info
from jdOctopus.model.swipe import swipe
from jdOctopus.model.point import point



import json
import requests

from jdOctopus.index import newOctopus
from jdOctopus.tool import interceptor, exist

class text:

    def __init__(self, text):
        octopus = newOctopus()
        self.addr = octopus.addr
        self.devices = octopus.devices
        self.headers = octopus.headers
        self.text = text

    def clickByOCR(self, uuids=""):
        if uuids == "":
            uuids = self.devices
        url = self.addr + "/clickByOCR"
        data = {
            'uuids': uuids,
            'text': self.text
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=self.headers).text)
        interceptor(text)

    def clickByXml(self, uuids=""):
        if uuids == "":
            uuids = self.devices
        url = self.addr + "/clickByXml"
        data = {
            'uuids': uuids,
            'text': self.text
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=self.headers).text)
        interceptor(text)

    def existByOCR(self, uuids=""):
        if uuids == "":
            uuids = self.devices
        url = self.addr + "/existTextByOCR"
        data = {
            'uuids': uuids,
            'text': self.text
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=self.headers).text)
        return exist(text)

    def existByXML(self, uuids=""):
        if uuids == "":
            uuids = self.devices
        url = self.addr + "/existTextByXML"
        data = {
            'uuids': uuids,
            'text': self.text
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=self.headers).text)
        return exist(text)

    def input(self, uuids=""):
        if uuids == "":
            uuids = self.devices
        url = self.addr + "/inputText"
        data = {
            'uuids': uuids,
            'text': self.text
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=self.headers).text)
        interceptor(text)

    def getPointsByXML(self, uuids=""):
        if uuids == "":
            uuids = self.devices
        url = self.addr + "/getPointsByXML"
        data = {
            'uuids': uuids,
            'text': self.text
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=self.headers).text)
        interceptor(text)
        return text["data"]

    def getPointsByOCR(self, uuids=""):
        if uuids == "":
            uuids = self.devices
        url = self.addr + "/getPointsByOCR"
        data = {
            'uuids': uuids,
            'text': self.text
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=self.headers).text)
        interceptor(text)
        return text["data"]


import json
import requests

from jdOctopus.index import newOctopus
from jdOctopus.tool import interceptor

class info:

    @staticmethod
    def getOCR(uuids=""):
        octopus = newOctopus()
        if uuids == "":
            uuids = octopus.devices
        url = octopus.addr + "/getOCRInfo"
        data = {
            'uuids': uuids
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=octopus.headers).text)
        interceptor(text)
        return text["data"]

    @staticmethod
    def getXML(uuids=""):
        octopus = newOctopus()
        if uuids == "":
            uuids = octopus.devices
        url = octopus.addr + "/getHierarchy"
        data = {
            'uuids': uuids
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=octopus.headers).text)
        interceptor(text)
        return text["data"]


import setuptools 
from setuptools import setup
setup(
      name='jdOctopus',
      version='0.3',
      description='jd-octopus py version',
      url='http://dqa.jd.com/octopus',
      author='renran',
      author_email='1114802403@qq.com',
      license='MIT',
      packages=setuptools.find_packages(),
      zip_safe=False,
      )


import json
import requests

from jdOctopus.index import newOctopus
from jdOctopus.tool import interceptor

class swipe:

    @staticmethod
    def swipe(points, uuids=""):
        octopus = newOctopus()
        if uuids == "":
            uuids = octopus.devices
        url = octopus.addr + "/swipe"
        data = {
            'uuids': uuids,
            'points': points
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=octopus.headers).text)
        interceptor(text)

    @staticmethod
    def smoothSwipe(points, uuids=""):
        octopus = newOctopus()
        if uuids == "":
            uuids = octopus.devices
        url = octopus.addr + "/smoothSwipe"
        data = {
            'uuids': uuids,
            'points': points
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=octopus.headers).text)
        interceptor(text)

    @staticmethod
    def verticalRoll(extent, uuids=""):
        octopus = newOctopus()
        if uuids == "":
            uuids = octopus.devices
        url = octopus.addr + "/verticalRoll"
        data = {
            'uuids': uuids,
            'extent': extent
        }
        text = json.loads(requests.post(url=url, data=json.dumps(data), headers=octopus.headers).text)
        interceptor(text)